@@ -30,6 +30,7 @@ setGeneric("%termin%", function(x, table) standardGeneric("%termin%"))
 #'  compare,BFindepSample,missing,data.frame-method
 #'  compare,BFlinearModel,missing,data.frame-method
 #'  compare,BFmetat,missing,data.frame-method
+#'  compare,BFproportion,missing,data.frame-method
 #'  compare,BFcontingencyTable,BFcontingencyTable,data.frame-method
 #'  compare,BFcontingencyTable,missing,data.frame-method
 #'  compare,BFmcmc,BFmcmc,ANY-method
@@ -55,9 +56,16 @@ setGeneric("%termin%", function(x, table) standardGeneric("%termin%"))
 #' compare(mod1, mod2) 
 setGeneric("compare", function(numerator, denominator, data, ...) standardGeneric("compare"))
 
-#' Take an object and redo the computation (useful for sampling)
+#' Recompute a Bayes factor computation or MCMC object. 
+#' 
+#' Take an object and redo the computation (useful for sampling). In cases where sampling is 
+#' used to compute the Bayes factor, the estimate of the precision of new samples will be added
+#' to the estimate precision of the old sample will be added to produce a new estimate of the 
+#' precision.
 #' @param x object to recompute
 #' @param progress report progress of the computation?
+#' @param multicore Use multicore, if available
+#' @param callback callback function for third-party interfaces 
 #' @param ... arguments passed to and from related methods
 #' @return Returns an object of the same type, after repeating the sampling (perhaps with more iterations)
 #' @export
@@ -78,7 +86,7 @@ setGeneric("compare", function(numerator, denominator, data, ...) standardGeneri
 #' ## Sample from posterior distribution of model above, and recompute:
 #' chains = posterior(bf, iterations = 1000, progress = FALSE)
 #' newChains = recompute(chains, iterations = 1000, progress=FALSE)     
-setGeneric("recompute", function(x, progress=options()$BFprogress, ...) standardGeneric("recompute"))
+setGeneric("recompute", function(x, progress=options()$BFprogress, multicore = FALSE, callback = function(...) as.integer(0), ...) standardGeneric("recompute"))
 
 #' Sample from the posterior distribution of one of several models.
 #' 
