@@ -173,7 +173,7 @@ anovaBF <-
     
     if(multicore){
       message("Note: Progress bars and callbacks are suppressed when running multicore.")
-      if(!require(doMC, quietly = TRUE)){
+      if(!requireNamespace("doMC", quietly = TRUE)){
         stop("Required package (doMC) missing for multicore functionality.")
       } 
       
